# -*- coding: utf-8 -*-

"""This module contains the controller classes of the application."""

from turbogears import controllers, expose, flash, widgets

from turbogears.widgets import TableForm, FieldSet, TextField


def make_kid(template):
    return template.replace(
        'http://genshi.edgewall.org/', 'http://purl.org/kid/ns#')


genshi_form = TableForm(name='form',
    template = TableForm.template, engine_name='genshi',
    fields=3*[FieldSet("testfields",
        template = FieldSet.template, engine_name='genshi',
        legend="Genshi Fieldset", fields=3*[TextField('text',
        template = TextField.template, engine_name='genshi',
        attrs=dict(size=32, maxlength=128), label="Genshi Textfield:")])],
    submit_text='Genshi form')

kid_form = TableForm(name='form',
    template = make_kid(TableForm.template), engine_name='kid',
    fields=3*[FieldSet("testfields",
        template = make_kid(FieldSet.template), engine_name='kid',
        legend="Kid Fieldset", fields=3*[TextField('text',
        template = make_kid(TextField.template), engine_name='kid',
        attrs=dict(size=32, maxlength=128), label="Kid Textfield")])],
        submit_text='Kid form')

mixed_form_1 = TableForm(name='form',
    template = TableForm.template, engine_name='genshi',
    fields=3*[FieldSet("testfields", engine_name='kid',
        template = make_kid(FieldSet.template),
        legend="Kid Fieldset", fields=3*[TextField('text',
        template = TextField.template, engine_name='genshi',
        attrs=dict(size=32, maxlength=128), label="Genshi Textfield:")])],
        submit_text='Genshi form')

mixed_form_2 = TableForm(name='form',
    template = make_kid(TableForm.template), engine_name='kid',
    fields=3*[FieldSet("testfields",
        template = FieldSet.template, engine_name='genshi',
        legend="Genshi Fieldset", fields=3*[TextField('text',
        template = make_kid(TextField.template), engine_name='kid',
        attrs=dict(size=32, maxlength=128), label="Kid Textfield:")])],
        submit_text='Kid form')


class Root(controllers.RootController):
    """The root controller of the application."""

    @expose(template="widget_test.templates.welcome")
    def index(self):
        """"Show the welcome page."""
        flash(_(u"Your application is now running"))
        return dict()

    @expose(template="widget_test.templates.result")
    def result(self):
        """Show the benchmarking result."""
        return dict()

    @expose(template="widget_test.templates.forms")
    def forms_genshi_genshi(self):
        """Display Genshi forms on a Genshi page."""
        return dict(form=genshi_form)

    @expose(template="kid:widget_test.templates.forms")
    def forms_genshi_kid(self):
        """Display Genshi forms on a Kid page."""
        return dict(form=genshi_form)

    @expose(template="widget_test.templates.forms")
    def forms_kid_genshi(self):
        """Display Kid forms on a Genshi page."""
        return dict(form=kid_form)

    @expose(template="kid:widget_test.templates.forms")
    def forms_kid_kid(self):
        """Display Kid forms on a Kid page."""
        return dict(form=kid_form)

    @expose(template="widget_test.templates.forms")
    def forms_mixed_1_genshi(self):
        """Display mixed forms on a Genshi page."""
        return dict(form=mixed_form_1)

    @expose(template="kid:widget_test.templates.forms")
    def forms_mixed_1_kid(self):
        """Display mixed forms on a Kid page."""
        return dict(form=mixed_form_1)

    @expose(template="widget_test.templates.forms")
    def forms_mixed_2_genshi(self):
        """Display mixed forms on a Genshi page."""
        return dict(form=mixed_form_2)

    @expose(template="kid:widget_test.templates.forms")
    def forms_mixed_2_kid(self):
        """Display mixed forms on a Kid page."""
        return dict(form=mixed_form_2)
